# Binaural Analysis

This section provides an overview of the binaural analysis tools available in Soundscapy. It includes a brief description of each tool, as well as information on how to access and use them.

::: soundscapy.audio.analysis_settings
    options:
        show_root_heading: false
        show_root_toc_entry: false

## Binaural Metrics

::: soundscapy.audio.binaural
    show_submodules: true

::: soundscapy.audio.metrics
    show_submodules: true

## Parallel Processing

::: soundscapy.audio.parallel_processing
    show_submodules: true

